@@ -1,5 +1,10 @@
 from .kit import *
-from .validators.string_validator import contains_chinese, remove_chinese
+from .validators.string_validator import (
+    contains_chinese,
+    remove_chinese,
+    contains_special_symbols,
+    remove_special_symbols,
+)
 from .validators.html_validator import validate_html, validate_html_fix
 from .kits.title_kit import check_title, shorten_title, generate_title
 from .kits.des_kit import generate_html
@@ -9,6 +14,8 @@ from .kits.cat_kit import predict_cat_direct, predict_cat_gradual
 __all__ = [
     "contains_chinese",
     "remove_chinese",
+    "contains_special_symbols",
+    "remove_special_symbols",
     "validate_html",
     "validate_html_fix",
     "check_title",
