@@ -32,13 +32,20 @@ def _create_validate_func(choices: list) -> Callable[[str], Tuple[bool, Any]]:
         if not choices:
             return True, values
 
+        # values 必须是列表，且不能为空
+        if not values or not isinstance(values, list):
+            return False, None
+
         # 有choices时进行验证
         validated_values = []
         for value in values:
             validated_value = auto_validate(choices, value)
-            if not validated_value:
-                return False, None
-            validated_values.append(validated_value)
+            if validated_value:
+                validated_values.append(validated_value)
+
+        if len(validated_values) < 1:
+            return False, None
+
         return True, validated_values
 
     return validate_func
@@ -58,5 +65,5 @@ def fill_attr(dispatcher: ModelDispatcher, message_info: dict, group: str, choic
         执行结果
     """
     validate_func = _create_validate_func(choices)
-    result, _ = dispatcher.execute_with_group(message_info, group, format_json=True, validate_func=validate_func)
+    result, _ = dispatcher.execute_with_group(message_info, group, format_json=True, validate_func=validate_func)  # type: ignore
     return result
