@@ -4,13 +4,15 @@
 """
 
 from .html_validator import check_allowed_tags
-from .string_validator import contains_chinese, remove_chinese
+from .string_validator import contains_chinese, remove_chinese, contains_special_symbols, remove_special_symbols
 from .value_validator import validate_dict, validate_string
 
 __all__ = [
     'check_allowed_tags',
     'contains_chinese',
     'remove_chinese',
+    'contains_special_symbols',
+    'remove_special_symbols',
     'validate_dict',
     'validate_string',
 ]
