@@ -8,25 +8,7 @@ from funcguard.printer import print_line
 from funcguard.core import timeout_handler
 from typing import Dict, Tuple, Any, Optional
 from ..message import prepare_messages, rebuild_messages_single_image, convert_images_to_base64
-
-
-# 图片下载相关的错误关键词列表
-IMAGE_DOWNLOAD_ERROR_KEYWORDS = [
-    "Download the media resource timed out",
-    "Failed to download multimodal content",
-    "Download multimodal file timed out",
-]
-
-# 默认的重试关键词列表
-DEFAULT_RETRY_KEYWORDS = [
-    "Too many requests",
-    "Allocated quota exceeded, please increase your quota limit",
-    "Max retries exceeded with url",
-    "Requests rate limit exceeded, please try again later",
-    "Free credits temporarily have rate limits",  # vercel
-]
-
-DEFAULT_RETRY_KEYWORDS.extend(IMAGE_DOWNLOAD_ERROR_KEYWORDS)
+from .retry_config import IMAGE_DOWNLOAD_ERROR_KEYWORDS, DEFAULT_RETRY_KEYWORDS, DEFAULT_RETRY_API_KEYWORDS
 
 
 class RetryHandler:
@@ -34,7 +16,17 @@ class RetryHandler:
 
     def __init__(self, platform: str):
         self.platform = platform
-        self.retry_keywords = DEFAULT_RETRY_KEYWORDS
+        # 获取全局图片缓存
+        self.image_cache = None
+        try:
+            # 注意：必须在这里导入，避免循环引用
+            # dispatcher.py 导入 message.convert_to_json，而 utils.retry_handler 又导入 dispatcher.ModelDispatcher
+            # 如果在模块级别导入会造成循环引用错误
+            from ..dispatcher import ModelDispatcher
+
+            self.image_cache = ModelDispatcher.get_image_cache()
+        except ImportError:
+            pass
 
     def prepare_request_data(self, messages: Any, message_info: Optional[Dict]) -> Tuple[Any, Dict]:
         """准备请求数据"""
@@ -83,8 +75,13 @@ class RetryHandler:
                 # hasattr 检查 response 是否有 json 方法
                 elif hasattr(response, 'json'):
                     res = response.json()
-                    error = res.get("error", res.get("errors", {}))
-                    error_message = error.get("message", str(e))
+                    # 判断 res 是否是列表
+                    if isinstance(res, list):
+                        res = res[0]
+                    error_message = res.get("message", "")  # cerebras_openai
+                    if not error_message:
+                        error = res.get("error", res.get("errors", {}))
+                        error_message = error.get("message", str(e))
 
             except (AttributeError, ValueError):
                 error_message = str(e)
@@ -93,7 +90,7 @@ class RetryHandler:
 
     def should_retry_for_rate_limit(self, error_message: str) -> bool:
         """判断是否因为限流而重试"""
-        return any(keyword in error_message for keyword in self.retry_keywords)
+        return any(keyword in error_message for keyword in DEFAULT_RETRY_KEYWORDS)
 
     def should_retry_for_image_error(self, error_message: str, message_config: Dict) -> bool:
         """判断是否因为图片错误而重试"""
@@ -123,8 +120,10 @@ class RetryHandler:
 
             # 第3次尝试时，检测图片格式并进行base64转换
             if api_retry_count == 1 and img_list:
-                print(f"尝试将图片转换为base64格式...")
-                img_list = convert_images_to_base64(img_list)
+                # print(f"尝试将图片转换为base64格式...")
+                img_list = convert_images_to_base64(img_list, self.image_cache)
+                # 更新message_config，确保转换后的base64图片在后续重试中继续使用
+                # message_config["img_list"] = img_list
 
             messages = rebuild_messages_single_image(
                 self.platform,
@@ -151,6 +150,10 @@ class RetryHandler:
 
         print("输入图片数量超过限制 或 图片输入格式/解析错误，正在（ 限制图片数量 = 1 ）然后重试...")
 
+        # 只使用第一张图片，并更新message_config
+        # if message_config["img_list"]:
+        #     message_config["img_list"] = [message_config["img_list"][0]]
+
         messages = rebuild_messages_single_image(
             self.platform,
             message_config["system_prompt"],
@@ -196,12 +199,8 @@ class RetryHandler:
             should_retry, updated_messages = self.handle_image_error(messages, message_config)
             return should_retry, updated_messages, False
 
-        elif "Request limit exceeded" in error_message:  # 适用于 modelscope
-            print("模型每日请求超过限制")
-            return True, messages, True  # 需要重试且需要切换API密钥
-
-        elif "The free tier of the model has been exhausted" in error_message:  # 适用于 dashscope
-            print("免费额度已用完")
+        elif any(keyword in error_message for keyword in DEFAULT_RETRY_API_KEYWORDS):
+            print("模型每日请求超过限制 或 免费额度已用完")
             return True, messages, True  # 需要重试且需要切换API密钥
 
         else:
